function ldangdiam, a0, base, lam, ldcoef

;;;  This function returns the squared visibility (ies) corresponding to
;;;  limb-darkened angular diameter (a0) given in milliarcsec,  
;;;  the baseline (base) given in metres, the 
;;;  wavelength of the observations (lam) also given in metres, and
;;;  the limb-darkening coefficient (ldcoef)
;;;  
;;;  a0 = limb-darkened angular diameter, this is a constant
;;;  base and lam have length n>1 and they need to be the same length.
;;;  ldcoef = constant, often obtained from CLARET (2000) [coeff= 'u']
;;;
;;;
;;;  It should be called as
;;; IDL>   vis2 = ldangdiam(a0,base,lam, ldcoef)


const = 1./((1-ldcoef)/2. + ldcoef/3.)
pii = !dpi
conversion = 206264798.0839162d0

xvar = pii * base * a0(0)/conversion/lam
fterm = (1-ldcoef) * beselj(xvar,1)/xvar
sterm = ldcoef*(pii/2.)^0.5 * beselj(xvar,1.5)/xvar^1.5
y = const * (fterm+sterm)

return, y^2
end
